==> waldur_api_client-0.1.0-py3-none-any.whl: waldur_api_client/models/rmq_subscription.py <==
import datetime
from typing import Any, TypeVar
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

T = TypeVar("T", bound="RmqSubscription")


@_attrs_define
class RmqSubscription:
    """
    Attributes:
        created (datetime.datetime):
        uuid (UUID):
        source_ip (str):
    """

    created: datetime.datetime
    uuid: UUID
    source_ip: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        created = self.created.isoformat()

        uuid = str(self.uuid)

        source_ip = self.source_ip

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "created": created,
                "uuid": uuid,
                "source_ip": source_ip,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        created = isoparse(d.pop("created"))

        uuid = UUID(d.pop("uuid"))

        source_ip = d.pop("source_ip")

        rmq_subscription = cls(
            created=created,
            uuid=uuid,
            source_ip=source_ip,
        )

        rmq_subscription.additional_properties = d
        return rmq_subscription

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> waldur_api_client-7.7.0-py3-none-any.whl: waldur_api_client/models/rmq_subscription.py <==
import datetime
from collections.abc import Mapping
from typing import Any, TypeVar
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

T = TypeVar("T", bound="RmqSubscription")


@_attrs_define
class RmqSubscription:
    """
    Attributes:
        created (datetime.datetime):
        uuid (UUID):
        source_ip (str):
    """

    created: datetime.datetime
    uuid: UUID
    source_ip: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        created = self.created.isoformat()

        uuid = str(self.uuid)

        source_ip = self.source_ip

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "created": created,
                "uuid": uuid,
                "source_ip": source_ip,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        created = isoparse(d.pop("created"))

        uuid = UUID(d.pop("uuid"))

        source_ip = d.pop("source_ip")

        rmq_subscription = cls(
            created=created,
            uuid=uuid,
            source_ip=source_ip,
        )

        rmq_subscription.additional_properties = d
        return rmq_subscription

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
